@@ -1,4 +1,4 @@
-get_predictions_wbm <- function(model, fitfram, ci.lvl, linv, type, terms, typical, condition, ...) {
+get_predictions_wbm <- function(model, fitfram, ci.lvl, linv, type, terms, condition, ...) {
   # does user want standard errors?
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
@@ -15,7 +15,7 @@ get_predictions_wbm <- function(model, fitfram, ci.lvl, linv, type, terms, typic
   else
     ref <- NULL
 
-  clean_terms <- .get_cleaned_terms(terms)
+  clean_terms <- .clean_terms(terms)
 
   if (type == "sim") {
 
