@@ -31,11 +31,6 @@ if (suppressWarnings(
     ggpredict(fit, c("age", "RIAGENDR"))
   })
 
-  test_that("ggaverage, svyglm", {
-    ggaverage(fit, "age")
-    ggaverage(fit, c("age", "RIAGENDR"))
-  })
-
   test_that("ggeffect, svyglm", {
     ggeffect(fit, "age")
     ggeffect(fit, c("age", "RIAGENDR"))
